# ModelJobConfig

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**stage** | **str** |  | 
**job_type** | **str** |  | 
**analysis_method** | **str** |  | [optional] 
**model_job_id** | **str** |  | 
**client_id** | **str** |  | 
**cohort_window_count** | **float** |  | [optional] 
**train_model_job_id** | **str** |  | [optional] 
**container_config** | [**ContainerConfig**](ContainerConfig.md) |  | 
**pipeline_config** | [**PipelineConfig**](PipelineConfig.md) |  | 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)

